#
# spec file for package python-python-subunit
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-python-subunit
Version:        1.3.0
Release:        lp151.2.3.1
Summary:        Python implementation of subunit test streaming protocol
License:        Apache-2.0 OR BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://launchpad.net/subunit
Source:         https://files.pythonhosted.org/packages/source/p/python-subunit/python-subunit-%{version}.tar.gz
Source99:       %{name}-rpmlintrc
# PATCH-FIX-OPENSUSE speilicke@suse.com -- Filters are installed in /usr/bin.
Patch0:         python-subunit-filter-path.patch
BuildRequires:  %{python_module fixtures}
BuildRequires:  %{python_module setuptools}
# SECTION test requirements
BuildRequires:  %{python_module testscenarios}
BuildRequires:  %{python_module testtools >= 0.9.34}
BuildRequires:  %{python_module unittest2}
# /SECTION
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-extras
Requires:       python-testtools >= 0.9.34
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
Subunit is a streaming protocol for test results. The protocol is human
readable. The components of the protocol conceptually fit into the xUnit
TestCase->TestResult interaction.

Subunit comes with command line filters to process a subunit stream and
language bindings for python, C, C++ and shell.

%prep
%setup -q -n python-subunit-%{version}
%patch0 -p1
# Remove shebang from non-executable files
sed -i -e "1d" python/subunit/run.py

%build
%python_build

%install
%python_install
#NOTE(saschpe): The testsuite demands executables:
%{python_expand chmod +x %{buildroot}%{$python_sitelib}/subunit/tests/sample-*.py
 find %{buildroot}%{$python_sitelib}/subunit/tests/ -type f -name "sample-*.py" -exec sed -i "s|#!%{_bindir}/env python|#!%__$python|" {} \;
 $python -m compileall -d %{$python_sitelib} %{buildroot}%{$python_sitelib}/subunit/tests/
 $python -O -m compileall -d %{$python_sitelib} %{buildroot}%{$python_sitelib}/subunit/tests/
 %fdupes -s %{buildroot}%{$python_sitelib}
}
for bin in subunit-2to1 subunit2csv subunit-1to2 subunit-filter subunit-ls \
    subunit-notify subunit-stats subunit-tags subunit-output subunit2gtk \
    subunit2junitxml subunit2pyunit tap2subunit subunit2disk
    do
    %python_clone -a %{buildroot}%{_bindir}/$bin
done

%check
patch -p1 -R < %{PATCH0}
export PYTHONPATH="$PWD/python"
%python_exec -m testtools.run subunit.test_suite

%post
%{python_install_alternative subunit-2to1 subunit2csv subunit-1to2 subunit-filter subunit-ls
    subunit-notify subunit-stats subunit-tags subunit-output subunit2gtk
    subunit2junitxml subunit2pyunit tap2subunit subunit2disk}

%postun
%python_uninstall_alternative subunit-2to1

%files %{python_files}
%doc README.rst NEWS
%python_alternative %{_bindir}/subunit2csv
%python_alternative %{_bindir}/subunit-2to1
%python_alternative %{_bindir}/subunit-1to2
%python_alternative %{_bindir}/subunit-filter
%python_alternative %{_bindir}/subunit-ls
%python_alternative %{_bindir}/subunit-notify
%python_alternative %{_bindir}/subunit-stats
%python_alternative %{_bindir}/subunit-tags
%python_alternative %{_bindir}/subunit-output
%python_alternative %{_bindir}/subunit2gtk
%python_alternative %{_bindir}/subunit2junitxml
%python_alternative %{_bindir}/subunit2pyunit
%python_alternative %{_bindir}/tap2subunit
%python_alternative %{_bindir}/subunit2disk
%{python_sitelib}/subunit
%{python_sitelib}/python_subunit-%{version}-py*.egg-info

%changelog
* Tue Nov  6 2018 Todd R <toddrme2178@gmail.com>
- Add missing unittest2 dependency.
* Mon Aug  6 2018 tchvatal@suse.com
- Version update to 1.3.0:
  * Fix make_stream_binary with FileIO object inputs
  * Add a --rename flag to subunit-filter
* Mon Oct  2 2017 jengelh@inai.de
- Ensure neutrality of description.
* Wed Sep 27 2017 tbechtold@suse.com
- Use update-alternatives for binaries. That way, the binaries are
  also available from the python2 package.
* Mon Jul 10 2017 toddrme2178@gmail.com
- Fix wrong-script-interpreter rpmlint error.
* Sun Apr 23 2017 aloisio@gmx.com
- Added fixtures build requirement
* Fri Apr  7 2017 aloisio@gmx.com
- Converted to single-spec (with great help from Jan Matejek)
* Fri Sep  2 2016 tbechtold@suse.com
- update to 1.2.0:
  * Fixed handling of incomplete writes with eventlet on Python3.
  * Added subunit2disk, which explodes a stream out to files on disk.
  * Unencapsulated strings and encapsulated stdout will be forwarded by
    subunit-2to1.
  * SUBUNIT_FORMATTER which has not been honoured for years is now
    removed from the codebase.
* Mon Jul 27 2015 seife+obs@b1-systems.com
- fix RHEL7 build by disabling %%py_compile (done by rpmbuild anyway)
* Mon Dec 29 2014 p.drouand@gmail.com
- Update to version 1.0.0
  + Tests have been fixed with testtools 1.2.0 and above.
  + With testtools 1.4.0 and above import errors are now
  shown in detail by ``subunit.run``.
- Fix build on Factory
* Sat Sep 27 2014 dmueller@suse.com
- update to 0.0.21:
  * Brown bag bugfix - 0.0.20's setup.py referenced cvs not csv.
    (Robert Collins, #1361924)
  * subunit2csv is now installed when using pip.
    (Robert Collins, #1279669)
  * testscenarios is now a test dependency, not an install dependency.
    (Arfrever Frehtes Taifersar Arahesis, #1292757)
  * The python-subunit tarball can now have setup run from the current
    directory. (Robert Collins, #1361857)
  * ``subunit.run`` in Python will now exit 0 as long as the test stream has
    been generated correctly - this has always been the intent but API friction
    with testtools had prevented it working.
    (Robert Collins)
- Remove python-testscenarios dependency; not needed anymore
* Thu Feb 13 2014 speilicke@suse.com
- Implement update-alternatives
* Thu Jan 30 2014 speilicke@suse.com
- Update to version 0.0.18:
  + Fix compatibility with testtools 0.9.35 which dropped the 'all' compat
    symbol. This breaks support for Python versions lower than 2.6.
- Changes from version 0.0.17:
  + Add subunit-output tool that can generate a Subunit v2 bytestream from
    arguments passed on the command line. (Thomi Richards, #1252084)
- Add /usr/bin/subunit-output
- Add python-subunit-filter-path.patch:
  + Fix filters path in testsuite
- Properly run testsuite
- Fix requirements
* Mon Jan 13 2014 dmueller@suse.com
- update to 0.0.16:
  * Perl files should now honour perl system config.
  * Python 3.1 and 3.2 have an inconsistent memoryview implementation which
  required a workaround for NUL byte detection. (Robert Collins, #1216246)
  * The test suite was failing 6 tests due to testtools changing it's output
  formatting of exceptions. (Robert Collins)
  * V2 parser errors now set appropriate mime types for the encapsulated packet
  data and the error message. (Robert Collins)
  * When tests fail to import python subunit.run -l ... will now write a
  subunit file attachment listing the failed imports and exit 2
- Fix package requires
* Tue Sep  3 2013 dmueller@suse.com
- update to 0.0.15:
  * Clients of subunit did not expect memoryview objects in StreamResult events.
  * Memoryview and struct were mutually incompatible in 2.7.3 and 3.2.
  * Memoryview detection was broken and thus it's use was never really tested.
  * TestProtocol2's tag tests were set sort order dependent.
  * TestTestProtocols' test_tags_both was set sort order dependent.
  * TestTestProtocols' test_*_details were dictionary sort order dependent.
  * TestSubUnitTags's test_add_tag was also se sort order dependent.
* Fri Jul 19 2013 dmueller@suse.com
- update to 0.0.13:
  * Fix GPL licensing issue
  * subunit-stats no longer outputs encapsulated stdout as subunit.
  * The logic for subunit.run is now importable via python -
    subunit.run.main. (Robert Collins, #606770)
* Sun Jun  2 2013 dmueller@suse.com
- update to 0.0.12:
  * fix data corruption bug in v2 protocol streaming
* Mon Apr 29 2013 dmueller@suse.com
- update to 0.0.11:
  * v2 protocol draft included in this release. The v2 protocol trades off human
  readability for a massive improvement in robustness, the ability to represent
  concurrent tests in a single stream, cheaper parsing, and that provides
  significantly better in-line debugging support and structured forwarding
  of non-test data (such as stdout or stdin data).
  * make_stream_binary is now public for reuse. (Robert Collins)
  * Streams with no fileno() attribute are now supported, but they are not
  checked for being in binary mode: be sure to take care of that if using
  the library yourself. (Robert Collins)
* Thu Jan 17 2013 cfarrell@suse.com
- license update: Apache-2.0 or BSD-3-Clause
  Look at the README file
* Tue Jan 15 2013 saschpe@suse.de
- Run testsuite
- Package README and NEWS
* Tue Jan 15 2013 dmueller@suse.com
- Initial packaging (0.0.9)
